package net.sf.oqt.core;

import static org.fest.assertions.Assertions.assertThat;
import static org.junit.Assert.*;

import java.io.File;
import java.io.IOException;

import org.apache.maven.model.Build;
import org.apache.maven.project.MavenProject;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class SerializerTest {

    private MavenProject project = null;
    
    private Serializer s = null;
    
    @Before
    public void setUp() throws Exception {
        project = new MavenProject();
        project.setBuild(new Build());
        project.getBuild().setDirectory((new File("./junit")).getAbsolutePath());
    }

    @After
    public void tearDown() throws Exception {
    }

    @Test
    public void testSerializerCtr() throws IOException {
        File outputDir = new File(project.getBuild().getDirectory());
        File outputFile = new File(outputDir.getAbsolutePath() + "querytranslator/output.ser");
        assertThat(outputFile).isNotNull().doesNotExist();
        s = new Serializer(project);
        assertThat(s).isNotNull();
        assertThat(outputDir).isNotNull().exists();
        assertThat(outputFile).isNotNull().doesNotExist();
        //cleanup
        assertThat((new File(outputDir.getAbsolutePath() + "/querytranslator").delete())).isTrue();
        assertThat((new File(outputDir.getAbsolutePath()).delete())).isTrue();
    }

    @Test
    public void testSerializerCtrOutputExists() throws IOException {
        File outputDir = new File(project.getBuild().getDirectory());
        if (!outputDir.exists()) {
            outputDir.mkdir();
            (new File(outputDir.getAbsolutePath() + "/querytranslator")).mkdir();
        }
        File outputFile = new File(outputDir.getAbsoluteFile() + "/querytranslator/output.ser");
        outputFile.createNewFile();
        assertThat(outputFile).isNotNull().exists();
        s = new Serializer(project);
        assertThat(s).isNotNull();
        assertThat(outputDir).isNotNull().exists();
        assertThat(outputFile).isNotNull().exists();
        //cleanup
        assertThat(outputFile.delete()).isTrue();
        assertThat((new File(outputDir.getAbsolutePath() + "/querytranslator").delete())).isTrue();
        assertThat((new File(outputDir.getAbsolutePath()).delete())).isTrue();

    }
    
    @Test
    public void serializeDeserialize() {
        
    }

}
