/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.maven;

import static org.fest.assertions.Assertions.assertThat;

import java.io.File;
import java.io.IOException;
import java.util.Collection;

import net.sf.oqt.core.CoreFactory;
import net.sf.oqt.core.Serializer;
import net.sf.oqt.jpa.testentities.TableA;
import net.sf.oqt.jpa.testentities.TestInfo;
import net.sf.oqt.maven.QueryTranslatorTranslateMojo;
import net.sf.oqt.model.EntityVO;
import net.sf.oqt.model.PackageVO;
import net.sf.oqt.model.QueryVO;
import net.sf.oqt.model.ResultVO;

import org.apache.maven.model.Build;
import org.apache.maven.monitor.logging.DefaultLog;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.project.MavenProject;
import org.codehaus.plexus.logging.console.ConsoleLogger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;


public class QueryTranslatorTranslateMojoTest {

	private QueryTranslatorTranslateMojo mojo = null;
	private MavenProject project = null;
	private File outputDir = null;
	
	@Before
	public void setUp() throws Exception {
		outputDir = new File("target/test");
		if (!outputDir.exists()) {
			outputDir.mkdir();
		}
		project = new MavenProject();
		project.setLogger(new ConsoleLogger(4, "junit"));
		project.setBuild(new Build());
		project.getBuild().setDirectory(outputDir.getAbsolutePath());
		System.out.println("OutputDir = " + project.getBuild().getDirectory());
		mojo = new QueryTranslatorTranslateMojo();
		mojo.setProject(project);
		mojo.setLog(new DefaultLog(new ConsoleLogger(0, "junit")));
		mojo.setDictionary(TestInfo.DICTIONARY_DERBY);
		mojo.setDriverName(TestInfo.DRIVER_DERBY);
		mojo.setUrl(TestInfo.URL_DERBY);
		mojo.getPackageNames().add(TableA.class.getPackage().getName());
	}

	@After
	public void tearDown() throws Exception {
		CoreFactory.shutdown();
		if (outputDir.exists()) {
			outputDir.delete();
		}
	}

	@Test
	public void testExecute() throws MojoExecutionException, MojoFailureException, ClassNotFoundException, IOException {
		mojo.execute();
		File outputSer = new File(project.getBuild().getDirectory() + "/querytranslator/output.ser");
		assertThat(outputSer).isNotNull().exists();
		Serializer s = new Serializer(project);
		ResultVO r = s.deserialize();
		assertThat(r).isNotNull();
		Collection<PackageVO> packages = r.getPackages();
		assertThat(packages).isNotNull().isNotEmpty().hasSize(3);
		Collection<EntityVO> entities = r.getPackages().iterator().next().getEntities();
		assertThat(entities).isNotNull().isNotEmpty().hasSize(TestInfo.numberOfEntities - TestInfo.numberOfEntitiesInGenericPackage - TestInfo.numberOfEntitiesInSubPackage);
		Collection<QueryVO> queries = entities.iterator().next().getQueries();
		assertThat(queries).isNotNull().isNotEmpty().hasSize(4);
		QueryVO query = queries.iterator().next();
		assertThat(query).isNotNull();
		assertThat(query.getSQLQuery()).isNotNull().isNotEmpty();
	}

}
